Mistral Installation Guide
==========================

.. toctree::
   :maxdepth: 2

   get_started.rst
   install.rst
   verify.rst
   next-steps.rst
   dashboard_guide
   installation_guide
   mistralclient_guide

The Workflow service (mistral) enables setting up task relations that have to be
 executed in a particular order, called workflows.

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial
<https://docs.openstack.org/install-guide/>`_.
